@@ -24,6 +24,9 @@ import pkgutil
 import sys
 import types
 
+# We don't want pyc or __pycache__ in the checkers module.
+sys.dont_write_bytecode = True
+
 path = os.path.dirname(os.path.abspath(__file__))
 sys.path.append(path)
 
@@ -45,7 +48,7 @@ def checks():
         # Does the module have a "run" function
         if isinstance(getattr(mod, 'run', None), types.FunctionType):
             # has a run method, yield it
-            yield name, mod
+            yield getattr(mod, 'CHECK_NAME', name), mod
 
 
 def title_print(msg):
